@@ -1,17 +1,12 @@
 import argparse
-import pathlib
-import logging
 import importlib
-import re
-import sys
+import logging
+import pathlib
 import shutil
-from typing import List, Dict
+from typing import List, Set
 
+from mypy_boto3.submodules import SUBMODULES, Submodule
 from mypy_boto3.version import __version__ as version
-from mypy_boto3.submodules import (
-    SUBMODULES,
-    Submodule,
-)
 
 ROOT_PATH = pathlib.Path(__file__).absolute().parent
 CACHE_PATH = ROOT_PATH / "cache.txt"
@@ -86,6 +81,10 @@ def main() -> None:
         log_level = logging.CRITICAL
 
     logger = get_logger(log_level)
+    logger.warning(
+        "This tool is no longer required for anntations to work."
+        " Remove it: `pip uninstall mypy_boto3`"
+    )
     if args.clean:
         file_paths = [
             ROOT_PATH / "cache.txt",
@@ -96,6 +95,10 @@ def main() -> None:
             if file_path.exists():
                 logger.info("Removing file %s", file_path)
                 file_path.unlink()
+        (ROOT_PATH / "boto3_init_gen.py").write_text((ROOT_PATH / "boto3_init_stub.py").read_text())
+        (ROOT_PATH / "boto3_session_gen.py").write_text(
+            (ROOT_PATH / "boto3_session_stub.py").read_text()
+        )
         for submodule in SUBMODULES:
             submodule_path = ROOT_PATH / submodule.import_name
             if submodule_path.exists():
@@ -114,7 +117,7 @@ def main() -> None:
             (
                 "You can now uninstall boto3-stubs with:\n\n"
                 "    python -m pip uninstall %s\n\n"
-                "If you want to continue using it and recreate index, run:\n\n"
+                "If you want to use auto-typing for boto3.client/resource functions, run:\n\n"
                 "    mypy_boto3\n"
             ),
             " ".join(package_names),
@@ -143,7 +146,7 @@ def add_package_to_index(boto3_name: str) -> None:
     Add new package to index and rebuild it if package is new.
     """
     active_boto3_names: Set[str] = {boto3_name}
-    active_submodule = None
+    active_submodule = SUBMODULES[0]
     logger = get_logger(logging.INFO)
     if CACHE_PATH.exists():
         active_boto3_names.update(CACHE_PATH.read_text().split(","))
@@ -168,8 +171,9 @@ def add_package_to_index(boto3_name: str) -> None:
 
 def _get_proxy_contents(module_name: str) -> str:
     service_module = importlib.import_module(module_name)
-    all_names = "\n    ".join(['"{}",'.format(i) for i in service_module.__all__])
-    import_names = "\n    ".join(["{},".format(i) for i in service_module.__all__])
+    module_all: List[str] = getattr(service_module, "__all__", [])
+    all_names = "\n    ".join(['"{}",'.format(i) for i in module_all])
+    import_names = "\n    ".join(["{},".format(i) for i in module_all])
     return "from {} import (\n    {}\n)\n\n__all__ = (\n    {}\n)\n".format(
         module_name, import_names, all_names
     )
@@ -188,7 +192,9 @@ def build_package_methods(logger: logging.Logger) -> None:
 
         active_submodules.append(submodule)
         logger.info(
-            "Discovered %s service stubs in %s", submodule.class_name, submodule.pypi_name,
+            "Discovered %s service stubs in %s",
+            submodule.class_name,
+            submodule.pypi_name,
         )
 
     for submodule in active_submodules:
@@ -210,7 +216,8 @@ def build_package_methods(logger: logging.Logger) -> None:
         )
         imports.append(
             "from mypy_boto3.{} import {}Client".format(
-                submodule.import_name, submodule.class_name,
+                submodule.import_name,
+                submodule.class_name,
             )
         )
         if submodule.has_resource:
@@ -232,38 +239,52 @@ def build_package_methods(logger: logging.Logger) -> None:
             )
             imports.append(
                 "from mypy_boto3.{} import {}ServiceResource".format(
-                    submodule.import_name, submodule.class_name,
+                    submodule.import_name,
+                    submodule.class_name,
                 )
             )
 
     if not init_client_functions:
         init_client_functions.append(
             FUNCTION_TEMPLATE.format(
-                overload="", name="client", service_name_type="str", return_type="Any",
+                overload="",
+                name="client",
+                service_name_type="str",
+                return_type="Any",
             )
         )
     if not init_resource_functions:
         init_resource_functions.append(
             FUNCTION_TEMPLATE.format(
-                overload="", name="resource", service_name_type="str", return_type="Any",
+                overload="",
+                name="resource",
+                service_name_type="str",
+                return_type="Any",
             )
         )
     if not session_client_functions:
         session_client_functions.append(
             METHOD_TEMPLATE.format(
-                overload="", name="client", service_name_type="str", return_type="Any",
+                overload="",
+                name="client",
+                service_name_type="str",
+                return_type="Any",
             )
         )
     if not session_resource_functions:
         session_resource_functions.append(
             METHOD_TEMPLATE.format(
-                overload="", name="resource", service_name_type="str", return_type="Any",
+                overload="",
+                name="resource",
+                service_name_type="str",
+                return_type="Any",
             )
         )
 
     init_contents: List[str] = [
         "import sys",
-        "from typing import overload, Any",
+        "from typing import overload, Any, Union",
+        "from botocore.config import Config",
         "if sys.version_info >= (3, 8):",
         "    from typing import Literal",
         "else:",
@@ -276,7 +297,8 @@ def build_package_methods(logger: logging.Logger) -> None:
 
     session_contents: List[str] = [
         "import sys",
-        "from typing import overload, Any",
+        "from typing import overload, Any, Union",
+        "from botocore.config import Config",
         "if sys.version_info >= (3, 8):",
         "    from typing import Literal",
         "else:",
@@ -289,7 +311,11 @@ def build_package_methods(logger: logging.Logger) -> None:
     session_contents.extend(session_resource_functions)
 
     write_text(ROOT_PATH / "boto3_init_gen.py", "\n".join(init_contents), logger)
+    logger.info("Generated annotations for boto3.client and boto3.resource functions")
     write_text(ROOT_PATH / "boto3_session_gen.py", "\n".join(session_contents), logger)
+    logger.info(
+        "Generated annotations for boto3.Session.client and boto3.Session.resource functions"
+    )
 
 
 def write_text(path: pathlib.Path, text: str, logger: logging.Logger) -> None:
@@ -308,36 +334,43 @@ def build_package_stubs(submodule: Submodule, logger: logging.Logger) -> None:
         submodule_path.mkdir(exist_ok=True)
 
     write_text(
-        submodule_path / "__init__.py", _get_proxy_contents(submodule.module_name), logger,
+        submodule_path / "__init__.py",
+        _get_proxy_contents(submodule.module_name),
+        logger,
     )
     write_text(
         submodule_path / "client.py",
         _get_proxy_contents("{}.client".format(submodule.module_name)),
         logger,
     )
+    logger.info("Generated mypy_boto3.%s.client module" % submodule.import_name)
     write_text(
         submodule_path / "type_defs.py",
         _get_proxy_contents("{}.type_defs".format(submodule.module_name)),
         logger,
     )
+    logger.info("Generated mypy_boto3.%s.type_defs module" % submodule.import_name)
     if submodule.has_resource:
         write_text(
             submodule_path / "service_resource.py",
             _get_proxy_contents("{}.service_resource".format(submodule.module_name)),
             logger,
         )
+        logger.info("Generated mypy_boto3.%s.service_resource module" % submodule.import_name)
     if submodule.has_waiter:
         write_text(
             submodule_path / "waiter.py",
             _get_proxy_contents("{}.waiter".format(submodule.module_name)),
             logger,
         )
+        logger.info("Generated mypy_boto3.%s.waiter module" % submodule.import_name)
     if submodule.has_paginator:
         write_text(
             submodule_path / "paginator.py",
             _get_proxy_contents("{}.paginator".format(submodule.module_name)),
             logger,
         )
+        logger.info("Generated mypy_boto3.%s.paginator module" % submodule.import_name)
 
 
 def log_install_info(logger: logging.Logger) -> None:
