@@ -1,6 +1,6 @@
 import importlib
 import importlib.util
-from typing import List, Dict, Any
+from typing import List
 
 
 class Submodule:
@@ -28,7 +28,7 @@ class Submodule:
 
     def get_all_names(self) -> List[str]:
         service_module = importlib.import_module(self.module_name)
-        return service_module.__all__
+        return getattr(service_module, "__all__", [])
 
 
 SUBMODULES: List[Submodule] = [
@@ -72,6 +72,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_amp",
+        import_name="amp",
+        boto3_name="amp",
+        class_name="PrometheusService",
+        pypi_name="mypy-boto3-amp",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_amplify",
         import_name="amplify",
@@ -82,6 +92,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_amplifybackend",
+        import_name="amplifybackend",
+        boto3_name="amplifybackend",
+        class_name="AmplifyBackend",
+        pypi_name="mypy-boto3-amplifybackend",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_apigateway",
         import_name="apigateway",
@@ -122,6 +142,26 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=False,
     ),
+    Submodule(
+        module_name="mypy_boto3_appflow",
+        import_name="appflow",
+        boto3_name="appflow",
+        class_name="Appflow",
+        pypi_name="mypy-boto3-appflow",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
+    Submodule(
+        module_name="mypy_boto3_appintegrations",
+        import_name="appintegrations",
+        boto3_name="appintegrations",
+        class_name="AppIntegrationsService",
+        pypi_name="mypy-boto3-appintegrations",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
     Submodule(
         module_name="mypy_boto3_application_autoscaling",
         import_name="application_autoscaling",
@@ -182,6 +222,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_auditmanager",
+        import_name="auditmanager",
+        boto3_name="auditmanager",
+        class_name="AuditManager",
+        pypi_name="mypy-boto3-auditmanager",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
     Submodule(
         module_name="mypy_boto3_autoscaling",
         import_name="autoscaling",
@@ -222,6 +272,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_braket",
+        import_name="braket",
+        boto3_name="braket",
+        class_name="Braket",
+        pypi_name="mypy-boto3-braket",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_budgets",
         import_name="budgets",
@@ -352,6 +412,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=True,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_codeartifact",
+        import_name="codeartifact",
+        boto3_name="codeartifact",
+        class_name="CodeArtifact",
+        pypi_name="mypy-boto3-codeartifact",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_codebuild",
         import_name="codebuild",
@@ -400,7 +470,7 @@ SUBMODULES: List[Submodule] = [
         pypi_name="mypy-boto3-codeguruprofiler",
         has_resource=False,
         has_waiter=False,
-        has_paginator=False,
+        has_paginator=True,
     ),
     Submodule(
         module_name="mypy_boto3_codepipeline",
@@ -522,6 +592,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_connect_contact_lens",
+        import_name="connect_contact_lens",
+        boto3_name="connect-contact-lens",
+        class_name="ConnectContactLens",
+        pypi_name="mypy-boto3-connect-contact-lens",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
     Submodule(
         module_name="mypy_boto3_connectparticipant",
         import_name="connectparticipant",
@@ -542,6 +622,26 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_customer_profiles",
+        import_name="customer_profiles",
+        boto3_name="customer-profiles",
+        class_name="CustomerProfiles",
+        pypi_name="mypy-boto3-customer-profiles",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
+    Submodule(
+        module_name="mypy_boto3_databrew",
+        import_name="databrew",
+        boto3_name="databrew",
+        class_name="GlueDataBrew",
+        pypi_name="mypy-boto3-databrew",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_dataexchange",
         import_name="dataexchange",
@@ -602,6 +702,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_devops_guru",
+        import_name="devops_guru",
+        boto3_name="devops-guru",
+        class_name="DevopsGuru",
+        pypi_name="mypy-boto3-devops-guru",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_directconnect",
         import_name="directconnect",
@@ -722,6 +832,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=True,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_ecr_public",
+        import_name="ecr_public",
+        boto3_name="ecr-public",
+        class_name="ECRPublic",
+        pypi_name="mypy-boto3-ecr-public",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_ecs",
         import_name="ecs",
@@ -760,7 +880,7 @@ SUBMODULES: List[Submodule] = [
         pypi_name="mypy-boto3-elastic-inference",
         has_resource=False,
         has_waiter=False,
-        has_paginator=False,
+        has_paginator=True,
     ),
     Submodule(
         module_name="mypy_boto3_elasticache",
@@ -779,7 +899,7 @@ SUBMODULES: List[Submodule] = [
         class_name="ElasticBeanstalk",
         pypi_name="mypy-boto3-elasticbeanstalk",
         has_resource=False,
-        has_waiter=False,
+        has_waiter=True,
         has_paginator=True,
     ),
     Submodule(
@@ -822,6 +942,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=True,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_emr_containers",
+        import_name="emr_containers",
+        boto3_name="emr-containers",
+        class_name="EMRContainers",
+        pypi_name="mypy-boto3-emr-containers",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_es",
         import_name="es",
@@ -852,6 +982,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=False,
     ),
+    Submodule(
+        module_name="mypy_boto3_fis",
+        import_name="fis",
+        boto3_name="fis",
+        class_name="FIS",
+        pypi_name="mypy-boto3-fis",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
     Submodule(
         module_name="mypy_boto3_fms",
         import_name="fms",
@@ -952,6 +1092,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_greengrassv2",
+        import_name="greengrassv2",
+        boto3_name="greengrassv2",
+        class_name="GreengrassV2",
+        pypi_name="mypy-boto3-greengrassv2",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_groundstation",
         import_name="groundstation",
@@ -982,6 +1132,26 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_healthlake",
+        import_name="healthlake",
+        boto3_name="healthlake",
+        class_name="HealthLake",
+        pypi_name="mypy-boto3-healthlake",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
+    Submodule(
+        module_name="mypy_boto3_honeycode",
+        import_name="honeycode",
+        boto3_name="honeycode",
+        class_name="Honeycode",
+        pypi_name="mypy-boto3-honeycode",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_iam",
         import_name="iam",
@@ -992,6 +1162,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=True,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_identitystore",
+        import_name="identitystore",
+        boto3_name="identitystore",
+        class_name="IdentityStore",
+        pypi_name="mypy-boto3-identitystore",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
     Submodule(
         module_name="mypy_boto3_imagebuilder",
         import_name="imagebuilder",
@@ -1082,6 +1262,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_iotdeviceadvisor",
+        import_name="iotdeviceadvisor",
+        boto3_name="iotdeviceadvisor",
+        class_name="IoTDeviceAdvisor",
+        pypi_name="mypy-boto3-iotdeviceadvisor",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
     Submodule(
         module_name="mypy_boto3_iotevents",
         import_name="iotevents",
@@ -1102,6 +1292,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=False,
     ),
+    Submodule(
+        module_name="mypy_boto3_iotfleethub",
+        import_name="iotfleethub",
+        boto3_name="iotfleethub",
+        class_name="IoTFleetHub",
+        pypi_name="mypy-boto3-iotfleethub",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_iotsecuretunneling",
         import_name="iotsecuretunneling",
@@ -1112,6 +1312,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=False,
     ),
+    Submodule(
+        module_name="mypy_boto3_iotsitewise",
+        import_name="iotsitewise",
+        boto3_name="iotsitewise",
+        class_name="IoTSiteWise",
+        pypi_name="mypy-boto3-iotsitewise",
+        has_resource=False,
+        has_waiter=True,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_iotthingsgraph",
         import_name="iotthingsgraph",
@@ -1122,6 +1332,26 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_iotwireless",
+        import_name="iotwireless",
+        boto3_name="iotwireless",
+        class_name="IoTWireless",
+        pypi_name="mypy-boto3-iotwireless",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
+    Submodule(
+        module_name="mypy_boto3_ivs",
+        import_name="ivs",
+        boto3_name="ivs",
+        class_name="IVS",
+        pypi_name="mypy-boto3-ivs",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_kafka",
         import_name="kafka",
@@ -1262,6 +1492,26 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=False,
     ),
+    Submodule(
+        module_name="mypy_boto3_lexv2_models",
+        import_name="lexv2_models",
+        boto3_name="lexv2-models",
+        class_name="LexModelsV2",
+        pypi_name="mypy-boto3-lexv2-models",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
+    Submodule(
+        module_name="mypy_boto3_lexv2_runtime",
+        import_name="lexv2_runtime",
+        boto3_name="lexv2-runtime",
+        class_name="LexRuntimeV2",
+        pypi_name="mypy-boto3-lexv2-runtime",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
     Submodule(
         module_name="mypy_boto3_license_manager",
         import_name="license_manager",
@@ -1282,6 +1532,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_location",
+        import_name="location",
+        boto3_name="location",
+        class_name="LocationService",
+        pypi_name="mypy-boto3-location",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_logs",
         import_name="logs",
@@ -1292,6 +1552,36 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_lookoutequipment",
+        import_name="lookoutequipment",
+        boto3_name="lookoutequipment",
+        class_name="LookoutEquipment",
+        pypi_name="mypy-boto3-lookoutequipment",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
+    Submodule(
+        module_name="mypy_boto3_lookoutmetrics",
+        import_name="lookoutmetrics",
+        boto3_name="lookoutmetrics",
+        class_name="LookoutMetrics",
+        pypi_name="mypy-boto3-lookoutmetrics",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
+    Submodule(
+        module_name="mypy_boto3_lookoutvision",
+        import_name="lookoutvision",
+        boto3_name="lookoutvision",
+        class_name="LookoutforVision",
+        pypi_name="mypy-boto3-lookoutvision",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_machinelearning",
         import_name="machinelearning",
@@ -1312,6 +1602,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_macie2",
+        import_name="macie2",
+        boto3_name="macie2",
+        class_name="Macie2",
+        pypi_name="mypy-boto3-macie2",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_managedblockchain",
         import_name="managedblockchain",
@@ -1359,7 +1659,7 @@ SUBMODULES: List[Submodule] = [
         class_name="MediaConnect",
         pypi_name="mypy-boto3-mediaconnect",
         has_resource=False,
-        has_waiter=False,
+        has_waiter=True,
         has_paginator=True,
     ),
     Submodule(
@@ -1452,6 +1752,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_mgn",
+        import_name="mgn",
+        boto3_name="mgn",
+        class_name="mgn",
+        pypi_name="mypy-boto3-mgn",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_migrationhub_config",
         import_name="migrationhub_config",
@@ -1492,6 +1802,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_mwaa",
+        import_name="mwaa",
+        boto3_name="mwaa",
+        class_name="MWAA",
+        pypi_name="mypy-boto3-mwaa",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_neptune",
         import_name="neptune",
@@ -1502,6 +1822,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=True,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_network_firewall",
+        import_name="network_firewall",
+        boto3_name="network-firewall",
+        class_name="NetworkFirewall",
+        pypi_name="mypy-boto3-network-firewall",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_networkmanager",
         import_name="networkmanager",
@@ -1512,6 +1842,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_nimble",
+        import_name="nimble",
+        boto3_name="nimble",
+        class_name="NimbleStudio",
+        pypi_name="mypy-boto3-nimble",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_opsworks",
         import_name="opsworks",
@@ -1670,7 +2010,7 @@ SUBMODULES: List[Submodule] = [
         pypi_name="mypy-boto3-quicksight",
         has_resource=False,
         has_waiter=False,
-        has_paginator=False,
+        has_paginator=True,
     ),
     Submodule(
         module_name="mypy_boto3_ram",
@@ -1712,6 +2052,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=True,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_redshift_data",
+        import_name="redshift_data",
+        boto3_name="redshift-data",
+        class_name="RedshiftDataAPIService",
+        pypi_name="mypy-boto3-redshift-data",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_rekognition",
         import_name="rekognition",
@@ -1800,7 +2150,17 @@ SUBMODULES: List[Submodule] = [
         pypi_name="mypy-boto3-s3control",
         has_resource=False,
         has_waiter=False,
-        has_paginator=False,
+        has_paginator=True,
+    ),
+    Submodule(
+        module_name="mypy_boto3_s3outposts",
+        import_name="s3outposts",
+        boto3_name="s3outposts",
+        class_name="S3Outposts",
+        pypi_name="mypy-boto3-s3outposts",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
     ),
     Submodule(
         module_name="mypy_boto3_sagemaker",
@@ -1822,6 +2182,26 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_sagemaker_edge",
+        import_name="sagemaker_edge",
+        boto3_name="sagemaker-edge",
+        class_name="SagemakerEdgeManager",
+        pypi_name="mypy-boto3-sagemaker-edge",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
+    Submodule(
+        module_name="mypy_boto3_sagemaker_featurestore_runtime",
+        import_name="sagemaker_featurestore_runtime",
+        boto3_name="sagemaker-featurestore-runtime",
+        class_name="SagemakerFeatureStoreRuntime",
+        pypi_name="mypy-boto3-sagemaker-featurestore-runtime",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
     Submodule(
         module_name="mypy_boto3_sagemaker_runtime",
         import_name="sagemaker_runtime",
@@ -1912,6 +2292,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_servicecatalog_appregistry",
+        import_name="servicecatalog_appregistry",
+        boto3_name="servicecatalog-appregistry",
+        class_name="AppRegistry",
+        pypi_name="mypy-boto3-servicecatalog-appregistry",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_servicediscovery",
         import_name="servicediscovery",
@@ -2010,7 +2400,7 @@ SUBMODULES: List[Submodule] = [
         pypi_name="mypy-boto3-sqs",
         has_resource=True,
         has_waiter=False,
-        has_paginator=False,
+        has_paginator=True,
     ),
     Submodule(
         module_name="mypy_boto3_ssm",
@@ -2019,7 +2409,7 @@ SUBMODULES: List[Submodule] = [
         class_name="SSM",
         pypi_name="mypy-boto3-ssm",
         has_resource=False,
-        has_waiter=False,
+        has_waiter=True,
         has_paginator=True,
     ),
     Submodule(
@@ -2032,6 +2422,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_sso_admin",
+        import_name="sso_admin",
+        boto3_name="sso-admin",
+        class_name="SSOAdmin",
+        pypi_name="mypy-boto3-sso-admin",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
     Submodule(
         module_name="mypy_boto3_sso_oidc",
         import_name="sso_oidc",
@@ -2092,6 +2492,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=True,
     ),
+    Submodule(
+        module_name="mypy_boto3_synthetics",
+        import_name="synthetics",
+        boto3_name="synthetics",
+        class_name="Synthetics",
+        pypi_name="mypy-boto3-synthetics",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
     Submodule(
         module_name="mypy_boto3_textract",
         import_name="textract",
@@ -2102,6 +2512,26 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=False,
     ),
+    Submodule(
+        module_name="mypy_boto3_timestream_query",
+        import_name="timestream_query",
+        boto3_name="timestream-query",
+        class_name="TimestreamQuery",
+        pypi_name="mypy-boto3-timestream-query",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=True,
+    ),
+    Submodule(
+        module_name="mypy_boto3_timestream_write",
+        import_name="timestream_write",
+        boto3_name="timestream-write",
+        class_name="TimestreamWrite",
+        pypi_name="mypy-boto3-timestream-write",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
     Submodule(
         module_name="mypy_boto3_transcribe",
         import_name="transcribe",
@@ -2162,6 +2592,16 @@ SUBMODULES: List[Submodule] = [
         has_waiter=False,
         has_paginator=False,
     ),
+    Submodule(
+        module_name="mypy_boto3_wellarchitected",
+        import_name="wellarchitected",
+        boto3_name="wellarchitected",
+        class_name="WellArchitected",
+        pypi_name="mypy-boto3-wellarchitected",
+        has_resource=False,
+        has_waiter=False,
+        has_paginator=False,
+    ),
     Submodule(
         module_name="mypy_boto3_workdocs",
         import_name="workdocs",
